#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const jest_cli_1 = require("jest-cli");
const CONFIG = {
    globals: {
        'ts-jest': {
            babelConfig: {
                presets: ['react'],
                plugins: [
                    [
                        '@babel/proposal-class-properties',
                        '@babel/proposal-async-generator-functions',
                        '@babel/syntax-dynamic-import',
                        '@babel/syntax-object-rest-spread',
                        'react-intl-auto',
                        {
                            removePrefix: 'src/',
                        },
                    ],
                ],
            },
        },
    },
    transform: {
        '^.+\\.tsx?$': 'ts-jest',
    },
    transformIgnorePatterns: ['node_modules/(?!@curiostack)'],
    testRegex: '(/__tests__/.*|(\\.|/)(test|spec))\\.(jsx?|tsx?)$',
    moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx', 'json', 'node'],
    setupTestFrameworkScriptFile: '@curiostack/base-web/build/dev/testing/test-bundler.jsx',
    snapshotSerializers: ['enzyme-to-json/serializer'],
    moduleNameMapper: {
        '.*\\.(css|less|styl|scss|sass)$': '@curiostack/base-web/build/dev/testing/mocks/cssModule.js',
        '.*\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$': '@curiostack/base-web/build/dev/testing/mocks/image.js',
    },
};
function test() {
    return __awaiter(this, void 0, void 0, function* () {
        const cli_params = process.argv.slice(2);
        const jest_params = ['--config', JSON.stringify(CONFIG)].concat(cli_params);
        return jest_cli_1.run(jest_params);
    });
}
exports.test = test;
if (require.main === module) {
    test().catch(() => process.exit(1));
}
//# sourceMappingURL=test.js.map